#ifndef _NJB_USB_H_
#define _NJB_USB_H_

#define  LSW(x)          (uint16_t)(x)
#define  MSW(x)          (uint16_t)((uint32_t)(x) >> 16)

#define  LSL(x)          (uint32_t)(x)
#define  MSL(x)          (uint32_t)((uint64_t)(x) >> 32)


#define NJB_MINOR 64
#define UT_WRITE 0x00
#define UT_READ  0x80

#define USB_CONTROL_TIMEOUT 10000
#define USB_BULK_TIMEOUT (2*HZ)

#define NJB_VENDOR_ID      0x0471
#define NJB_PRODUCT_ID     0x0222
#define NJB_DEV_CLASS	   0xDC
#define NJB_DEV_SUBCLASS   0x00

#define NJB_BULK_EP	2
#define NJB_ENDPOINT_BULK                  2

#define NOMAD_MINOR   96
#define MAX_NO_OF_DEVICES 4

#define NAK_TIMEOUT (HZ)

#define IBUF_SIZE 0x1000
#define OBUF_SIZE 0xFE00

#define NJB_ENDPOINT_CONTROL               0
#define NJB_ENDPOINT_INTERRUPT_READ        4
#define NJB_ENDPOINT_INTERRUPT_WRITE       3
#define NJB_ENDPOINT_BULK_READ             2
#define NJB_ENDPOINT_BULK_WRITE            1

#define NJB_POWER_BATTERY       0x00
#define NJB_POWER_AC_CHARGED    0x01
#define NJB_POWER_AC_CHARGING   0x03

#define DEF_XFER_BLOCK_SIZE	    0x0000FE00
#define MAX_XFER_BLOCK_SIZE	    DEF_XFER_BLOCK_SIZE
#define XFER_BLOCK_HEADER_SIZE  68

#define NJB_RELEASE	0x00
#define NJB_CAPTURE	0x01

#define	NJB_CMD_PING						0x01
#define NJB_CMD_GET_DISK_USAGE				0x04
#define NJB_CMD_GET_FIRST_TRACK_TAG_HEADER	0x06
#define NJB_CMD_GET_NEXT_TRACK_TAG_HEADER	0x07
#define NJB_CMD_GET_TRACK_TAG				0x09
#define NJB_CMD_SEND_TRACK_TAG				0x0a
#define NJB_CMD_DELETE_TRACK				0x0b
#define NJB_CMD_REPLACE_TRACK_TAG			0x0c
#define NJB_CMD_REQUEST_TRACK				0x0d
#define NJB_CMD_TRANSFER_COMPLETE			0x0e
#define NJB_CMD_SEND_FILE_BLOCK				0x0f
#define NJB_CMD_RECEIVE_FILE_BLOCK			0x10
#define NJB_CMD_GET_FIRST_PLAYLIST_HEADER	0x11
#define NJB_CMD_GET_NEXT_PLAYLIST_HEADER	0x12
#define NJB_CMD_GET_PLAYLIST				0x14
#define NJB_CMD_CREATE_PLAYLIST				0x15
#define NJB_CMD_DELETE_PLAYLIST				0x16
#define NJB_CMD_ADD_TRACK_TO_PLAYLIST		0x17
#define NJB_CMD_QUEUE_TRACK					0x1b
#define NJB_CMD_PLAY_TRACK					0x1d
#define NJB_CMD_STOP_PLAY					0x1e
#define NJB_CMD_ELAPSED_TIME				0x22
#define NJB_CMD_CAPTURE_NJB					0x2b
#define NJB_CMD_RELEASE_NJB					0x2c
#define NJB_CMD_GET_EAX_SIZE				0x3a
#define NJB_CMD_GET_EAX						0x24
#define NJB_CMD_RENAME_PLAYLIST				0x40
#define NJB_CMD_SET_OWNER_STRING			0x41
#define NJB_CMD_GET_OWNER_STRING			0x42
#define NJB_CMD_GET_LIBRARY_COUNTER			0x43
#define NJB_CMD_SET_LIBRARY_COUNTER			0x44
#define NJB_CMD_ADD_MULTIPLE_TRACKS_TO_PLAYLIST	0x46
#define NJB_CMD_SEND_DATAFILE_TAG		0x48
#define NJB_CMD_DELETE_DATAFILE			0x49
#define NJB_CMD_GET_FIRST_DATAFILE_HEADER	0x4a
#define NJB_CMD_GET_NEXT_DATAFILE_HEADER	0x4b
#define NJB_CMD_GET_DATAFILE_TAG		0x4d
#define NJB_CMD_VERIFY_LAST_CMD			0xf0

#define NJB_VAL_GET_EAX				0x00
#define NJB_VAL_GET_EAX_UNKNOWN			0x01

#define NJB_OK                               0x00
#define NJB_FAILED                           0x01
#define NJB_DEVICE_BUSY                      0x02
#define NJB_STORAGE_FULL                     0x03
#define NJB_HD_GENERAL_ERROR                 0x04
#define NJB_SETTIME_REJECTED                 0x05

#define NJB_TRACK_NOT_FOUND                  0x10
#define NJB_TRACK_ALREADY_EXIST              0x11
#define NJB_TRACK_TITLE_MISSING              0x12
#define NJB_TRACK_CODEC_MISSING              0x13
#define NJB_TRACK_SIZE_MISSING               0x14
#define NJB_TRACK_IO_OPERATION_ABORTED       0x15
#define NJB_TRACK_READ_WRITE_ERROR           0x16
#define NJB_TRACK_NOT_OPENED                 0x17
#define NJB_TRACK_UPLOAD_DENIED              0x18

#define NJB_PLAYLIST_NOT_FOUND               0x20
#define NJB_PLAYLIST_EXISTS                  0x21
#define NJB_PLAYLIST_ITEM_NOT_FOUND          0x22
#define NJB_PLAYLIST_ITEM_EXISTS             0x23

#define NJB_MSG_QUEUED_AUDIO_STARTED         0x30
#define NJB_MSG_PLAYER_FINISHED              0x31

#define NJB_ERR_VOLUME_CONTROL_UNAVAILABLE   0x42

#define NJB_ERR_DATA_NOT_FOUND               0x60
#define NJB_DATA_NOT_OPENED                  0x67

#define NJB_PLAYER_NOT_CONNECTED             0x80
#define NJB_CANCELLED                        0x81
#define NJB_PORT_NOT_AVALIABLE               0x82
#define NJB_OUT_OF_MEMORY                    0x83
#define NJB_FILEOPEN_ERR                     0x84
#define NJB_ITEM_NOT_FOUND                   0x85
#define NJB_LOAD_COMPONENTS_FAILED           0x86
#define NJB_ID_INVALID                       0x87
#define NJB_FILETYPE_ILLEGAL                 0x88
#define NJB_LOADRES_FAIL                     0x89
#define NJB_FORMAT_NOT_FOUND                 0x8a
#define NJB_FILE_ALREADY_EXISTS              0x8b
#define NJB_LIB_CORRUPTED                    0x8c
#define NJB_LIB_BUSY                         0x8d
#define NJB_FILE_READ_WRITE_FAILED           0x8e
#define NJB_INVALID_FILEPATH                 0x8f
#define NJB_DISKFULL_FOR_DOWNLOAD            0x90
#define NJB_FILE_PLAYONLY                    0x91
#define NJB_UNDEFINED_ERR                    0xff

#endif
