#ifndef _NJBFS_H_
#define _NJBFS_H_

#define NJBFS_VERSION "0.1"

#define NJBFS_DEBUG 1


#include "njbfs_cache.h"



#define NJBFS_SUPER_MAGIC 0xFADE

#define NJBFS_MAX_LINE 255
#define NJBFS_MAXPATHLEN 1024
#define NJBFS_MAXVIRTUALDIRLEN 32

#define NJBFS_BLOCKSIZE 4096	/* max 4096 */
#define NJBFS_BLOCKSIZE_BITS 12	/* 2^x = blocksize */

struct njbfs_mount_data {
	int version;
	int active;
	__kernel_uid_t uid;
	__kernel_gid_t gid;
	__kernel_mode_t file_mode;
	__kernel_mode_t dir_mode;
	char root[NJBFS_MAXPATHLEN];	/* root directory */
	char mount_point[NJBFS_MAXPATHLEN];
};

#define NJBFS_MODE_TRACKS 1
#define NJBFS_MODE_PLAYLISTS 2
#define NJBFS_MODE_ALBUMS 3
#define NJBFS_MODE_ARTISTS 4

struct njbfs_sb_info {
	struct njbfs_mount_data mnt;
	struct semaphore sem;
	struct njbfs_dir_cache cache;
	struct nomad_usb_data *njb;
	int virtual_mode;
	char virtual_dir[NJBFS_MAXVIRTUALDIRLEN];
};

struct njbfs_fattr {
	unsigned long f_ino;
	umode_t f_mode;
	nlink_t f_nlink;
	uid_t f_uid;
	gid_t f_gid;
	kdev_t f_rdev;
	off_t f_size;
	time_t f_atime;
	time_t f_mtime;
	time_t f_ctime;
	unsigned long f_blksize;
	unsigned long f_blocks;
	u_int32_t fileid;	/* file id of the NJB */
	/* file name parsing */
	u_int32_t size;		/* size */
	char *codec;		/* codec frame */
	char *title;		/* title frame */
	char *artist;		/* artist frame */
	char *album;		/* album frame */
	char *genre;		/* genre frame */
	u_int32_t length;	/* optional frame: length in seconds */
	u_int32_t tracknum;	/* optional frame: album track number */
	track_t *track;		/* track */

};

#endif
