/*
 * USB Nomad Jukebox filesystem for Linux.
 *
 * Copyright (C) 2001 Jrg Prante <joergprante@gmx.de>
 *
 * based on ftpfs by Florin Malita <fmalita@yahoo.com>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */


#include <linux/kernel.h>
#include <linux/module.h>
#include <linux/fs.h>
#include <linux/usb.h>

#include "njbfs.h"
#include "njbfs_proc.h"


static int njbfs_readlink(struct dentry *dentry, char *buffer, int bufflen)
{
	struct inode *inode = dentry->d_inode;
	struct super_block *sb = inode->i_sb;
	struct njbfs_sb_info *info = sb->u.generic_sbp;

	char buf[NJBFS_MAXPATHLEN];
	struct njbfs_directory *dir;
	struct njbfs_dirlist_node *file;
	char *real_name;
	int res;

	njbfs_get_name(dentry->d_parent, buf);

	njbfs_lock(info);
	res = njbfs_cache_get(info, buf, &dir);
	njbfs_unlock(info);
	if (res < 0) {
		info("njbfs_cache_get failed");
		return res;
	}

	for (file = dir->head; file != NULL; file = file->next)
		if (strcmp(file->entry.name, dentry->d_name.name) == 0)
			break;
	if (!file) {
		info("file not found in cache");
		return -1;
	}

	real_name = file->entry.name + strlen(file->entry.name) + 4;

	return vfs_readlink(dentry, buffer, bufflen, real_name);
}

static int njbfs_follow_link(struct dentry *dentry, struct nameidata *nd)
{
	struct inode *inode = dentry->d_inode;
	struct super_block *sb = inode->i_sb;
	struct njbfs_sb_info *info = sb->u.generic_sbp;

	char buf[NJBFS_MAXPATHLEN];
	struct njbfs_directory *dir;
	struct njbfs_dirlist_node *file;
	char *real_name;
	int res;

	njbfs_get_name(dentry->d_parent, buf);
	dbg("%s", buf);

	njbfs_lock(info);
	res = njbfs_cache_get(info, buf, &dir);
	njbfs_unlock(info);

	if (res < 0) {
		info("njbfs_cache_get failed");
		return res;
	}

	for (file = dir->head; file != NULL; file = file->next)
		if (strcmp(file->entry.name, dentry->d_name.name) == 0)
			break;
	if (!file) {
		info("file not found in cache");
		return -1;
	}

	real_name = file->entry.name + strlen(file->entry.name) + 4;

	return vfs_follow_link(nd, real_name);
}

struct inode_operations njbfs_symlink_inode_operations = {
	readlink:njbfs_readlink,
	follow_link:njbfs_follow_link,
};
