/*
 * ID3 tool using mplib 0.6
 *
 * Install mplib 0.6 from http://mplib.sourceforge.net
 * with shared libs before building this tool:
 *
 * tar zxvf mplib-0.6.tar.gz
 * cd mplib-0.6
 * ./configure --enable-shared=yes
 * make
 * su -> root
 * make install
 *
 * This tool only shows the information of the ID3 tags of given MP3 files
 * and does no modification at all. The format of information display
 * is compatible to the njbfs file name parser format.
 *
 * Copyright (C) 2001 Jrg Prante <joergprante@gmx.de>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

#include <sys/types.h>
#include <sys/stat.h>
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include <unistd.h>
#include <mplib.h>


int main(int argc, char *argv[]) {
    id3_tag_list *taglist;
    id3_tag *tag;
    id3_content *content;
    id3_text_content *textcontent;
    int i, ret;
    int size;
    struct stat st;

    if (argc == 1)
        printf("Usage: id3tool <mp3-files>");

    for (i = 1; i < argc; i++) {
        printf("\nFile: %s\n", argv[i]);

        ret =stat(argv[i], &st);
        if (ret == 0)
            size = st.st_size;
        else
            size = 0;
        printf("    size={%d}", size);

        taglist = mp_get_tag_list_from_file(argv[i]);
        if (taglist) {
          do {
            tag = taglist->tag;
            if (tag) {
                content = mp_get_content(tag, MP_ARTIST);
                if (content) {
                    textcontent = mp_parse_artist(content);
                    printf(",artist={%s}", textcontent->text );
                }
                content = mp_get_content(tag, MP_TITLE);
                if (content) {
                    textcontent = mp_parse_title(content);
                    printf(",title={%s}", textcontent->text );
                }
                content = mp_get_content(tag, MP_ALBUM);
                if (content) {
                    textcontent = mp_parse_album(content);
                    printf(",album={%s}", textcontent->text );
                }
                content = mp_get_content(tag, MP_GENRE);
                if (content) {
                    textcontent = mp_parse_genre(content);
                    printf(",genre={%s}", textcontent->text );
                }
                content = mp_get_content(tag, MP_TRACK);
                if (content) {
                    textcontent = mp_parse_track(content);
                    printf(",track={%s}", textcontent->text );
                }
		/* mplib 0.6 does not provide track size code */
                content = mp_get_content_custom_at_pos(tag, "TSIZ", 0);
                if (content) {
                    textcontent = mp_parse_text(content);
                    printf(",size={%s}", textcontent->text );
                }
            }
            taglist = taglist->next;
          } while (taglist);
        }
        else {
            printf("<no tags found>");
        }
    }
    printf("\n");
    return 0;
}
